---
name: Bug Report
about: Create a bug report
title: ''
labels: bug
assignees: ''

---

###  Bug

<!-- A clear and concise description of what the bug is. Please include the full error stack trace, if applicable.-->

### To Reproduce

<!-- Steps to reproduce the behavior. Please include the code if possible. -->

### Repository version
<!-- Please provide the commit hash of the version you are using (running `git rev-parse HEAD`) in your report. -->
